# coding: utf-8

"""
    Midgard Public API

    The Midgard Public API queries THORChain and any chains linked via the Bifröst and prepares information about the network to be readily available for public users. The API parses transaction event data from THORChain and stores them in a time-series database to make time-dependent queries easy. Midgard does not hold critical information. To interact with THORChain protocol, users should query THORNode directly.  # noqa: E501

    OpenAPI spec version: 2.20.1
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class SwapHistoryItem(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'average_slip': 'str',
        'end_time': 'str',
        'rune_price_usd': 'str',
        'start_time': 'str',
        'synth_mint_average_slip': 'str',
        'synth_mint_count': 'str',
        'synth_mint_fees': 'str',
        'synth_mint_volume': 'str',
        'synth_mint_volume_usd': 'str',
        'synth_redeem_average_slip': 'str',
        'synth_redeem_count': 'str',
        'synth_redeem_fees': 'str',
        'synth_redeem_volume': 'str',
        'synth_redeem_volume_usd': 'str',
        'to_asset_average_slip': 'str',
        'to_asset_count': 'str',
        'to_asset_fees': 'str',
        'to_asset_volume': 'str',
        'to_asset_volume_usd': 'str',
        'to_rune_average_slip': 'str',
        'to_rune_count': 'str',
        'to_rune_fees': 'str',
        'to_rune_volume': 'str',
        'to_rune_volume_usd': 'str',
        'total_count': 'str',
        'total_fees': 'str',
        'total_volume': 'str',
        'total_volume_usd': 'str'
    }

    attribute_map = {
        'average_slip': 'averageSlip',
        'end_time': 'endTime',
        'rune_price_usd': 'runePriceUSD',
        'start_time': 'startTime',
        'synth_mint_average_slip': 'synthMintAverageSlip',
        'synth_mint_count': 'synthMintCount',
        'synth_mint_fees': 'synthMintFees',
        'synth_mint_volume': 'synthMintVolume',
        'synth_mint_volume_usd': 'synthMintVolumeUSD',
        'synth_redeem_average_slip': 'synthRedeemAverageSlip',
        'synth_redeem_count': 'synthRedeemCount',
        'synth_redeem_fees': 'synthRedeemFees',
        'synth_redeem_volume': 'synthRedeemVolume',
        'synth_redeem_volume_usd': 'synthRedeemVolumeUSD',
        'to_asset_average_slip': 'toAssetAverageSlip',
        'to_asset_count': 'toAssetCount',
        'to_asset_fees': 'toAssetFees',
        'to_asset_volume': 'toAssetVolume',
        'to_asset_volume_usd': 'toAssetVolumeUSD',
        'to_rune_average_slip': 'toRuneAverageSlip',
        'to_rune_count': 'toRuneCount',
        'to_rune_fees': 'toRuneFees',
        'to_rune_volume': 'toRuneVolume',
        'to_rune_volume_usd': 'toRuneVolumeUSD',
        'total_count': 'totalCount',
        'total_fees': 'totalFees',
        'total_volume': 'totalVolume',
        'total_volume_usd': 'totalVolumeUSD'
    }

    def __init__(self, average_slip=None, end_time=None, rune_price_usd=None, start_time=None, synth_mint_average_slip=None, synth_mint_count=None, synth_mint_fees=None, synth_mint_volume=None, synth_mint_volume_usd=None, synth_redeem_average_slip=None, synth_redeem_count=None, synth_redeem_fees=None, synth_redeem_volume=None, synth_redeem_volume_usd=None, to_asset_average_slip=None, to_asset_count=None, to_asset_fees=None, to_asset_volume=None, to_asset_volume_usd=None, to_rune_average_slip=None, to_rune_count=None, to_rune_fees=None, to_rune_volume=None, to_rune_volume_usd=None, total_count=None, total_fees=None, total_volume=None, total_volume_usd=None):  # noqa: E501
        """SwapHistoryItem - a model defined in Swagger"""  # noqa: E501
        self._average_slip = None
        self._end_time = None
        self._rune_price_usd = None
        self._start_time = None
        self._synth_mint_average_slip = None
        self._synth_mint_count = None
        self._synth_mint_fees = None
        self._synth_mint_volume = None
        self._synth_mint_volume_usd = None
        self._synth_redeem_average_slip = None
        self._synth_redeem_count = None
        self._synth_redeem_fees = None
        self._synth_redeem_volume = None
        self._synth_redeem_volume_usd = None
        self._to_asset_average_slip = None
        self._to_asset_count = None
        self._to_asset_fees = None
        self._to_asset_volume = None
        self._to_asset_volume_usd = None
        self._to_rune_average_slip = None
        self._to_rune_count = None
        self._to_rune_fees = None
        self._to_rune_volume = None
        self._to_rune_volume_usd = None
        self._total_count = None
        self._total_fees = None
        self._total_volume = None
        self._total_volume_usd = None
        self.discriminator = None
        self.average_slip = average_slip
        self.end_time = end_time
        self.rune_price_usd = rune_price_usd
        self.start_time = start_time
        self.synth_mint_average_slip = synth_mint_average_slip
        self.synth_mint_count = synth_mint_count
        self.synth_mint_fees = synth_mint_fees
        self.synth_mint_volume = synth_mint_volume
        self.synth_mint_volume_usd = synth_mint_volume_usd
        self.synth_redeem_average_slip = synth_redeem_average_slip
        self.synth_redeem_count = synth_redeem_count
        self.synth_redeem_fees = synth_redeem_fees
        self.synth_redeem_volume = synth_redeem_volume
        self.synth_redeem_volume_usd = synth_redeem_volume_usd
        self.to_asset_average_slip = to_asset_average_slip
        self.to_asset_count = to_asset_count
        self.to_asset_fees = to_asset_fees
        self.to_asset_volume = to_asset_volume
        self.to_asset_volume_usd = to_asset_volume_usd
        self.to_rune_average_slip = to_rune_average_slip
        self.to_rune_count = to_rune_count
        self.to_rune_fees = to_rune_fees
        self.to_rune_volume = to_rune_volume
        self.to_rune_volume_usd = to_rune_volume_usd
        self.total_count = total_count
        self.total_fees = total_fees
        self.total_volume = total_volume
        self.total_volume_usd = total_volume_usd

    @property
    def average_slip(self):
        """Gets the average_slip of this SwapHistoryItem.  # noqa: E501

        Float64 (Basis points, 0-10000, where 10000=100%), the weighted average (by count) of toAssetAverageSlip, toRuneAverageSlip, synthMintAverageSlip, synthRedeemAverageSlip. Big swaps have the same weight as small swaps.   # noqa: E501

        :return: The average_slip of this SwapHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._average_slip

    @average_slip.setter
    def average_slip(self, average_slip):
        """Sets the average_slip of this SwapHistoryItem.

        Float64 (Basis points, 0-10000, where 10000=100%), the weighted average (by count) of toAssetAverageSlip, toRuneAverageSlip, synthMintAverageSlip, synthRedeemAverageSlip. Big swaps have the same weight as small swaps.   # noqa: E501

        :param average_slip: The average_slip of this SwapHistoryItem.  # noqa: E501
        :type: str
        """
        if average_slip is None:
            raise ValueError("Invalid value for `average_slip`, must not be `None`")  # noqa: E501

        self._average_slip = average_slip

    @property
    def end_time(self):
        """Gets the end_time of this SwapHistoryItem.  # noqa: E501

        Int64, The end time of bucket in unix timestamp  # noqa: E501

        :return: The end_time of this SwapHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """Sets the end_time of this SwapHistoryItem.

        Int64, The end time of bucket in unix timestamp  # noqa: E501

        :param end_time: The end_time of this SwapHistoryItem.  # noqa: E501
        :type: str
        """
        if end_time is None:
            raise ValueError("Invalid value for `end_time`, must not be `None`")  # noqa: E501

        self._end_time = end_time

    @property
    def rune_price_usd(self):
        """Gets the rune_price_usd of this SwapHistoryItem.  # noqa: E501

        Float, the price of Rune based on the deepest USD pool at the end of the interval.   # noqa: E501

        :return: The rune_price_usd of this SwapHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._rune_price_usd

    @rune_price_usd.setter
    def rune_price_usd(self, rune_price_usd):
        """Sets the rune_price_usd of this SwapHistoryItem.

        Float, the price of Rune based on the deepest USD pool at the end of the interval.   # noqa: E501

        :param rune_price_usd: The rune_price_usd of this SwapHistoryItem.  # noqa: E501
        :type: str
        """
        if rune_price_usd is None:
            raise ValueError("Invalid value for `rune_price_usd`, must not be `None`")  # noqa: E501

        self._rune_price_usd = rune_price_usd

    @property
    def start_time(self):
        """Gets the start_time of this SwapHistoryItem.  # noqa: E501

        Int64, The beginning time of bucket in unix timestamp  # noqa: E501

        :return: The start_time of this SwapHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this SwapHistoryItem.

        Int64, The beginning time of bucket in unix timestamp  # noqa: E501

        :param start_time: The start_time of this SwapHistoryItem.  # noqa: E501
        :type: str
        """
        if start_time is None:
            raise ValueError("Invalid value for `start_time`, must not be `None`")  # noqa: E501

        self._start_time = start_time

    @property
    def synth_mint_average_slip(self):
        """Gets the synth_mint_average_slip of this SwapHistoryItem.  # noqa: E501

        Float64 (Basis points, 0-10000, where 10000=100%), the average slip for swaps from rune to synthetic asset. Big swaps have the same weight as small swaps   # noqa: E501

        :return: The synth_mint_average_slip of this SwapHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._synth_mint_average_slip

    @synth_mint_average_slip.setter
    def synth_mint_average_slip(self, synth_mint_average_slip):
        """Sets the synth_mint_average_slip of this SwapHistoryItem.

        Float64 (Basis points, 0-10000, where 10000=100%), the average slip for swaps from rune to synthetic asset. Big swaps have the same weight as small swaps   # noqa: E501

        :param synth_mint_average_slip: The synth_mint_average_slip of this SwapHistoryItem.  # noqa: E501
        :type: str
        """
        if synth_mint_average_slip is None:
            raise ValueError("Invalid value for `synth_mint_average_slip`, must not be `None`")  # noqa: E501

        self._synth_mint_average_slip = synth_mint_average_slip

    @property
    def synth_mint_count(self):
        """Gets the synth_mint_count of this SwapHistoryItem.  # noqa: E501

        Int64, count of rune to synthetic asset swaps  # noqa: E501

        :return: The synth_mint_count of this SwapHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._synth_mint_count

    @synth_mint_count.setter
    def synth_mint_count(self, synth_mint_count):
        """Sets the synth_mint_count of this SwapHistoryItem.

        Int64, count of rune to synthetic asset swaps  # noqa: E501

        :param synth_mint_count: The synth_mint_count of this SwapHistoryItem.  # noqa: E501
        :type: str
        """
        if synth_mint_count is None:
            raise ValueError("Invalid value for `synth_mint_count`, must not be `None`")  # noqa: E501

        self._synth_mint_count = synth_mint_count

    @property
    def synth_mint_fees(self):
        """Gets the synth_mint_fees of this SwapHistoryItem.  # noqa: E501

        Int64(e8), the fees collected from swaps from rune to synthetic asset (in rune)   # noqa: E501

        :return: The synth_mint_fees of this SwapHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._synth_mint_fees

    @synth_mint_fees.setter
    def synth_mint_fees(self, synth_mint_fees):
        """Sets the synth_mint_fees of this SwapHistoryItem.

        Int64(e8), the fees collected from swaps from rune to synthetic asset (in rune)   # noqa: E501

        :param synth_mint_fees: The synth_mint_fees of this SwapHistoryItem.  # noqa: E501
        :type: str
        """
        if synth_mint_fees is None:
            raise ValueError("Invalid value for `synth_mint_fees`, must not be `None`")  # noqa: E501

        self._synth_mint_fees = synth_mint_fees

    @property
    def synth_mint_volume(self):
        """Gets the synth_mint_volume of this SwapHistoryItem.  # noqa: E501

        Int64(e8), volume of swaps from rune to synthetic asset denoted in rune  # noqa: E501

        :return: The synth_mint_volume of this SwapHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._synth_mint_volume

    @synth_mint_volume.setter
    def synth_mint_volume(self, synth_mint_volume):
        """Sets the synth_mint_volume of this SwapHistoryItem.

        Int64(e8), volume of swaps from rune to synthetic asset denoted in rune  # noqa: E501

        :param synth_mint_volume: The synth_mint_volume of this SwapHistoryItem.  # noqa: E501
        :type: str
        """
        if synth_mint_volume is None:
            raise ValueError("Invalid value for `synth_mint_volume`, must not be `None`")  # noqa: E501

        self._synth_mint_volume = synth_mint_volume

    @property
    def synth_mint_volume_usd(self):
        """Gets the synth_mint_volume_usd of this SwapHistoryItem.  # noqa: E501

        Int64(e2), volume of swaps from rune to synthetic asset denoted in USD price of the rune in each swap  # noqa: E501

        :return: The synth_mint_volume_usd of this SwapHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._synth_mint_volume_usd

    @synth_mint_volume_usd.setter
    def synth_mint_volume_usd(self, synth_mint_volume_usd):
        """Sets the synth_mint_volume_usd of this SwapHistoryItem.

        Int64(e2), volume of swaps from rune to synthetic asset denoted in USD price of the rune in each swap  # noqa: E501

        :param synth_mint_volume_usd: The synth_mint_volume_usd of this SwapHistoryItem.  # noqa: E501
        :type: str
        """
        if synth_mint_volume_usd is None:
            raise ValueError("Invalid value for `synth_mint_volume_usd`, must not be `None`")  # noqa: E501

        self._synth_mint_volume_usd = synth_mint_volume_usd

    @property
    def synth_redeem_average_slip(self):
        """Gets the synth_redeem_average_slip of this SwapHistoryItem.  # noqa: E501

        Float64 (Basis points, 0-10000, where 10000=100%), the average slip for swaps from synthetic asset to rune. Big swaps have the same weight as small swaps   # noqa: E501

        :return: The synth_redeem_average_slip of this SwapHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._synth_redeem_average_slip

    @synth_redeem_average_slip.setter
    def synth_redeem_average_slip(self, synth_redeem_average_slip):
        """Sets the synth_redeem_average_slip of this SwapHistoryItem.

        Float64 (Basis points, 0-10000, where 10000=100%), the average slip for swaps from synthetic asset to rune. Big swaps have the same weight as small swaps   # noqa: E501

        :param synth_redeem_average_slip: The synth_redeem_average_slip of this SwapHistoryItem.  # noqa: E501
        :type: str
        """
        if synth_redeem_average_slip is None:
            raise ValueError("Invalid value for `synth_redeem_average_slip`, must not be `None`")  # noqa: E501

        self._synth_redeem_average_slip = synth_redeem_average_slip

    @property
    def synth_redeem_count(self):
        """Gets the synth_redeem_count of this SwapHistoryItem.  # noqa: E501

        Int64, count of synthetic asset to rune swaps  # noqa: E501

        :return: The synth_redeem_count of this SwapHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._synth_redeem_count

    @synth_redeem_count.setter
    def synth_redeem_count(self, synth_redeem_count):
        """Sets the synth_redeem_count of this SwapHistoryItem.

        Int64, count of synthetic asset to rune swaps  # noqa: E501

        :param synth_redeem_count: The synth_redeem_count of this SwapHistoryItem.  # noqa: E501
        :type: str
        """
        if synth_redeem_count is None:
            raise ValueError("Invalid value for `synth_redeem_count`, must not be `None`")  # noqa: E501

        self._synth_redeem_count = synth_redeem_count

    @property
    def synth_redeem_fees(self):
        """Gets the synth_redeem_fees of this SwapHistoryItem.  # noqa: E501

        Int64(e8), the fees collected from swaps from synthetic asset to rune (in rune)   # noqa: E501

        :return: The synth_redeem_fees of this SwapHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._synth_redeem_fees

    @synth_redeem_fees.setter
    def synth_redeem_fees(self, synth_redeem_fees):
        """Sets the synth_redeem_fees of this SwapHistoryItem.

        Int64(e8), the fees collected from swaps from synthetic asset to rune (in rune)   # noqa: E501

        :param synth_redeem_fees: The synth_redeem_fees of this SwapHistoryItem.  # noqa: E501
        :type: str
        """
        if synth_redeem_fees is None:
            raise ValueError("Invalid value for `synth_redeem_fees`, must not be `None`")  # noqa: E501

        self._synth_redeem_fees = synth_redeem_fees

    @property
    def synth_redeem_volume(self):
        """Gets the synth_redeem_volume of this SwapHistoryItem.  # noqa: E501

        Int64(e8), volume of swaps from synthetic asset to rune denoted in rune  # noqa: E501

        :return: The synth_redeem_volume of this SwapHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._synth_redeem_volume

    @synth_redeem_volume.setter
    def synth_redeem_volume(self, synth_redeem_volume):
        """Sets the synth_redeem_volume of this SwapHistoryItem.

        Int64(e8), volume of swaps from synthetic asset to rune denoted in rune  # noqa: E501

        :param synth_redeem_volume: The synth_redeem_volume of this SwapHistoryItem.  # noqa: E501
        :type: str
        """
        if synth_redeem_volume is None:
            raise ValueError("Invalid value for `synth_redeem_volume`, must not be `None`")  # noqa: E501

        self._synth_redeem_volume = synth_redeem_volume

    @property
    def synth_redeem_volume_usd(self):
        """Gets the synth_redeem_volume_usd of this SwapHistoryItem.  # noqa: E501

        Int64(e2), volume of swaps from synthetic asset to rune denoted in USD price of the rune in each swap  # noqa: E501

        :return: The synth_redeem_volume_usd of this SwapHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._synth_redeem_volume_usd

    @synth_redeem_volume_usd.setter
    def synth_redeem_volume_usd(self, synth_redeem_volume_usd):
        """Sets the synth_redeem_volume_usd of this SwapHistoryItem.

        Int64(e2), volume of swaps from synthetic asset to rune denoted in USD price of the rune in each swap  # noqa: E501

        :param synth_redeem_volume_usd: The synth_redeem_volume_usd of this SwapHistoryItem.  # noqa: E501
        :type: str
        """
        if synth_redeem_volume_usd is None:
            raise ValueError("Invalid value for `synth_redeem_volume_usd`, must not be `None`")  # noqa: E501

        self._synth_redeem_volume_usd = synth_redeem_volume_usd

    @property
    def to_asset_average_slip(self):
        """Gets the to_asset_average_slip of this SwapHistoryItem.  # noqa: E501

        Float64 (Basis points, 0-10000, where 10000=100%), the average slip for swaps from rune to asset. Big swaps have the same weight as small swaps   # noqa: E501

        :return: The to_asset_average_slip of this SwapHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._to_asset_average_slip

    @to_asset_average_slip.setter
    def to_asset_average_slip(self, to_asset_average_slip):
        """Sets the to_asset_average_slip of this SwapHistoryItem.

        Float64 (Basis points, 0-10000, where 10000=100%), the average slip for swaps from rune to asset. Big swaps have the same weight as small swaps   # noqa: E501

        :param to_asset_average_slip: The to_asset_average_slip of this SwapHistoryItem.  # noqa: E501
        :type: str
        """
        if to_asset_average_slip is None:
            raise ValueError("Invalid value for `to_asset_average_slip`, must not be `None`")  # noqa: E501

        self._to_asset_average_slip = to_asset_average_slip

    @property
    def to_asset_count(self):
        """Gets the to_asset_count of this SwapHistoryItem.  # noqa: E501

        Int64, count of swaps from rune to asset  # noqa: E501

        :return: The to_asset_count of this SwapHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._to_asset_count

    @to_asset_count.setter
    def to_asset_count(self, to_asset_count):
        """Sets the to_asset_count of this SwapHistoryItem.

        Int64, count of swaps from rune to asset  # noqa: E501

        :param to_asset_count: The to_asset_count of this SwapHistoryItem.  # noqa: E501
        :type: str
        """
        if to_asset_count is None:
            raise ValueError("Invalid value for `to_asset_count`, must not be `None`")  # noqa: E501

        self._to_asset_count = to_asset_count

    @property
    def to_asset_fees(self):
        """Gets the to_asset_fees of this SwapHistoryItem.  # noqa: E501

        Int64(e8), the fees collected from swaps from rune to asset (in rune)  # noqa: E501

        :return: The to_asset_fees of this SwapHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._to_asset_fees

    @to_asset_fees.setter
    def to_asset_fees(self, to_asset_fees):
        """Sets the to_asset_fees of this SwapHistoryItem.

        Int64(e8), the fees collected from swaps from rune to asset (in rune)  # noqa: E501

        :param to_asset_fees: The to_asset_fees of this SwapHistoryItem.  # noqa: E501
        :type: str
        """
        if to_asset_fees is None:
            raise ValueError("Invalid value for `to_asset_fees`, must not be `None`")  # noqa: E501

        self._to_asset_fees = to_asset_fees

    @property
    def to_asset_volume(self):
        """Gets the to_asset_volume of this SwapHistoryItem.  # noqa: E501

        Int64(e8), volume of swaps from rune to asset denoted in rune  # noqa: E501

        :return: The to_asset_volume of this SwapHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._to_asset_volume

    @to_asset_volume.setter
    def to_asset_volume(self, to_asset_volume):
        """Sets the to_asset_volume of this SwapHistoryItem.

        Int64(e8), volume of swaps from rune to asset denoted in rune  # noqa: E501

        :param to_asset_volume: The to_asset_volume of this SwapHistoryItem.  # noqa: E501
        :type: str
        """
        if to_asset_volume is None:
            raise ValueError("Invalid value for `to_asset_volume`, must not be `None`")  # noqa: E501

        self._to_asset_volume = to_asset_volume

    @property
    def to_asset_volume_usd(self):
        """Gets the to_asset_volume_usd of this SwapHistoryItem.  # noqa: E501

        Int64(e2), volume of swaps from rune to asset denoted in USD price of the rune in each swap  # noqa: E501

        :return: The to_asset_volume_usd of this SwapHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._to_asset_volume_usd

    @to_asset_volume_usd.setter
    def to_asset_volume_usd(self, to_asset_volume_usd):
        """Sets the to_asset_volume_usd of this SwapHistoryItem.

        Int64(e2), volume of swaps from rune to asset denoted in USD price of the rune in each swap  # noqa: E501

        :param to_asset_volume_usd: The to_asset_volume_usd of this SwapHistoryItem.  # noqa: E501
        :type: str
        """
        if to_asset_volume_usd is None:
            raise ValueError("Invalid value for `to_asset_volume_usd`, must not be `None`")  # noqa: E501

        self._to_asset_volume_usd = to_asset_volume_usd

    @property
    def to_rune_average_slip(self):
        """Gets the to_rune_average_slip of this SwapHistoryItem.  # noqa: E501

        Float64 (Basis points, 0-10000, where 10000=100%), the average slip for swaps from asset to rune. Big swaps have the same weight as small swaps   # noqa: E501

        :return: The to_rune_average_slip of this SwapHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._to_rune_average_slip

    @to_rune_average_slip.setter
    def to_rune_average_slip(self, to_rune_average_slip):
        """Sets the to_rune_average_slip of this SwapHistoryItem.

        Float64 (Basis points, 0-10000, where 10000=100%), the average slip for swaps from asset to rune. Big swaps have the same weight as small swaps   # noqa: E501

        :param to_rune_average_slip: The to_rune_average_slip of this SwapHistoryItem.  # noqa: E501
        :type: str
        """
        if to_rune_average_slip is None:
            raise ValueError("Invalid value for `to_rune_average_slip`, must not be `None`")  # noqa: E501

        self._to_rune_average_slip = to_rune_average_slip

    @property
    def to_rune_count(self):
        """Gets the to_rune_count of this SwapHistoryItem.  # noqa: E501

        Int64, count of swaps from asset to rune  # noqa: E501

        :return: The to_rune_count of this SwapHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._to_rune_count

    @to_rune_count.setter
    def to_rune_count(self, to_rune_count):
        """Sets the to_rune_count of this SwapHistoryItem.

        Int64, count of swaps from asset to rune  # noqa: E501

        :param to_rune_count: The to_rune_count of this SwapHistoryItem.  # noqa: E501
        :type: str
        """
        if to_rune_count is None:
            raise ValueError("Invalid value for `to_rune_count`, must not be `None`")  # noqa: E501

        self._to_rune_count = to_rune_count

    @property
    def to_rune_fees(self):
        """Gets the to_rune_fees of this SwapHistoryItem.  # noqa: E501

        Int64(e8), the fees collected from swaps from asset to rune (in rune)  # noqa: E501

        :return: The to_rune_fees of this SwapHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._to_rune_fees

    @to_rune_fees.setter
    def to_rune_fees(self, to_rune_fees):
        """Sets the to_rune_fees of this SwapHistoryItem.

        Int64(e8), the fees collected from swaps from asset to rune (in rune)  # noqa: E501

        :param to_rune_fees: The to_rune_fees of this SwapHistoryItem.  # noqa: E501
        :type: str
        """
        if to_rune_fees is None:
            raise ValueError("Invalid value for `to_rune_fees`, must not be `None`")  # noqa: E501

        self._to_rune_fees = to_rune_fees

    @property
    def to_rune_volume(self):
        """Gets the to_rune_volume of this SwapHistoryItem.  # noqa: E501

        Int64(e8), volume of swaps from asset to rune denoted in rune  # noqa: E501

        :return: The to_rune_volume of this SwapHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._to_rune_volume

    @to_rune_volume.setter
    def to_rune_volume(self, to_rune_volume):
        """Sets the to_rune_volume of this SwapHistoryItem.

        Int64(e8), volume of swaps from asset to rune denoted in rune  # noqa: E501

        :param to_rune_volume: The to_rune_volume of this SwapHistoryItem.  # noqa: E501
        :type: str
        """
        if to_rune_volume is None:
            raise ValueError("Invalid value for `to_rune_volume`, must not be `None`")  # noqa: E501

        self._to_rune_volume = to_rune_volume

    @property
    def to_rune_volume_usd(self):
        """Gets the to_rune_volume_usd of this SwapHistoryItem.  # noqa: E501

        Int64(e2), volume of swaps from asset to rune denoted in USD price of the rune in each swap  # noqa: E501

        :return: The to_rune_volume_usd of this SwapHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._to_rune_volume_usd

    @to_rune_volume_usd.setter
    def to_rune_volume_usd(self, to_rune_volume_usd):
        """Sets the to_rune_volume_usd of this SwapHistoryItem.

        Int64(e2), volume of swaps from asset to rune denoted in USD price of the rune in each swap  # noqa: E501

        :param to_rune_volume_usd: The to_rune_volume_usd of this SwapHistoryItem.  # noqa: E501
        :type: str
        """
        if to_rune_volume_usd is None:
            raise ValueError("Invalid value for `to_rune_volume_usd`, must not be `None`")  # noqa: E501

        self._to_rune_volume_usd = to_rune_volume_usd

    @property
    def total_count(self):
        """Gets the total_count of this SwapHistoryItem.  # noqa: E501

        Int64, toAssetCount + toRuneCount + synthMintCount + synthRedeemCount  # noqa: E501

        :return: The total_count of this SwapHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._total_count

    @total_count.setter
    def total_count(self, total_count):
        """Sets the total_count of this SwapHistoryItem.

        Int64, toAssetCount + toRuneCount + synthMintCount + synthRedeemCount  # noqa: E501

        :param total_count: The total_count of this SwapHistoryItem.  # noqa: E501
        :type: str
        """
        if total_count is None:
            raise ValueError("Invalid value for `total_count`, must not be `None`")  # noqa: E501

        self._total_count = total_count

    @property
    def total_fees(self):
        """Gets the total_fees of this SwapHistoryItem.  # noqa: E501

        Int64(e8), toAssetFees + toRuneFees + synthMintFees + synthRedeemFees  # noqa: E501

        :return: The total_fees of this SwapHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._total_fees

    @total_fees.setter
    def total_fees(self, total_fees):
        """Sets the total_fees of this SwapHistoryItem.

        Int64(e8), toAssetFees + toRuneFees + synthMintFees + synthRedeemFees  # noqa: E501

        :param total_fees: The total_fees of this SwapHistoryItem.  # noqa: E501
        :type: str
        """
        if total_fees is None:
            raise ValueError("Invalid value for `total_fees`, must not be `None`")  # noqa: E501

        self._total_fees = total_fees

    @property
    def total_volume(self):
        """Gets the total_volume of this SwapHistoryItem.  # noqa: E501

        Int64(e8), toAssetVolume + toRuneVolume + synthMintVolume + synthRedeemVolume (denoted in rune)   # noqa: E501

        :return: The total_volume of this SwapHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._total_volume

    @total_volume.setter
    def total_volume(self, total_volume):
        """Sets the total_volume of this SwapHistoryItem.

        Int64(e8), toAssetVolume + toRuneVolume + synthMintVolume + synthRedeemVolume (denoted in rune)   # noqa: E501

        :param total_volume: The total_volume of this SwapHistoryItem.  # noqa: E501
        :type: str
        """
        if total_volume is None:
            raise ValueError("Invalid value for `total_volume`, must not be `None`")  # noqa: E501

        self._total_volume = total_volume

    @property
    def total_volume_usd(self):
        """Gets the total_volume_usd of this SwapHistoryItem.  # noqa: E501

        Int64(e2), toAssetVolume + toRuneVolume + synthMintVolume + synthRedeemVolume (denoted in USD price of the rune in each swap)   # noqa: E501

        :return: The total_volume_usd of this SwapHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._total_volume_usd

    @total_volume_usd.setter
    def total_volume_usd(self, total_volume_usd):
        """Sets the total_volume_usd of this SwapHistoryItem.

        Int64(e2), toAssetVolume + toRuneVolume + synthMintVolume + synthRedeemVolume (denoted in USD price of the rune in each swap)   # noqa: E501

        :param total_volume_usd: The total_volume_usd of this SwapHistoryItem.  # noqa: E501
        :type: str
        """
        if total_volume_usd is None:
            raise ValueError("Invalid value for `total_volume_usd`, must not be `None`")  # noqa: E501

        self._total_volume_usd = total_volume_usd

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SwapHistoryItem, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SwapHistoryItem):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Midgard Public API

    The Midgard Public API queries THORChain and any chains linked via the Bifröst and prepares information about the network to be readily available for public users. The API parses transaction event data from THORChain and stores them in a time-series database to make time-dependent queries easy. Midgard does not hold critical information. To interact with THORChain protocol, users should query THORNode directly.  # noqa: E501

    OpenAPI spec version: 2.20.1
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class GenesisInf(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'hash': 'str',
        'height': 'int'
    }

    attribute_map = {
        'hash': 'hash',
        'height': 'height'
    }

    def __init__(self, hash=None, height=None):  # noqa: E501
        """GenesisInf - a model defined in Swagger"""  # noqa: E501
        self._hash = None
        self._height = None
        self.discriminator = None
        self.hash = hash
        self.height = height

    @property
    def hash(self):
        """Gets the hash of this GenesisInf.  # noqa: E501

        Genesis Block hash  # noqa: E501

        :return: The hash of this GenesisInf.  # noqa: E501
        :rtype: str
        """
        return self._hash

    @hash.setter
    def hash(self, hash):
        """Sets the hash of this GenesisInf.

        Genesis Block hash  # noqa: E501

        :param hash: The hash of this GenesisInf.  # noqa: E501
        :type: str
        """
        if hash is None:
            raise ValueError("Invalid value for `hash`, must not be `None`")  # noqa: E501

        self._hash = hash

    @property
    def height(self):
        """Gets the height of this GenesisInf.  # noqa: E501

        Genesis Block height  # noqa: E501

        :return: The height of this GenesisInf.  # noqa: E501
        :rtype: int
        """
        return self._height

    @height.setter
    def height(self, height):
        """Sets the height of this GenesisInf.

        Genesis Block height  # noqa: E501

        :param height: The height of this GenesisInf.  # noqa: E501
        :type: int
        """
        if height is None:
            raise ValueError("Invalid value for `height`, must not be `None`")  # noqa: E501

        self._height = height

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GenesisInf, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GenesisInf):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Midgard Public API

    The Midgard Public API queries THORChain and any chains linked via the Bifröst and prepares information about the network to be readily available for public users. The API parses transaction event data from THORChain and stores them in a time-series database to make time-dependent queries easy. Midgard does not hold critical information. To interact with THORChain protocol, users should query THORNode directly.  # noqa: E501

    OpenAPI spec version: 2.20.1
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class SaversHistoryItem(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'end_time': 'str',
        'savers_count': 'str',
        'savers_depth': 'str',
        'savers_units': 'str',
        'start_time': 'str'
    }

    attribute_map = {
        'end_time': 'endTime',
        'savers_count': 'saversCount',
        'savers_depth': 'saversDepth',
        'savers_units': 'saversUnits',
        'start_time': 'startTime'
    }

    def __init__(self, end_time=None, savers_count=None, savers_depth=None, savers_units=None, start_time=None):  # noqa: E501
        """SaversHistoryItem - a model defined in Swagger"""  # noqa: E501
        self._end_time = None
        self._savers_count = None
        self._savers_depth = None
        self._savers_units = None
        self._start_time = None
        self.discriminator = None
        self.end_time = end_time
        self.savers_count = savers_count
        self.savers_depth = savers_depth
        self.savers_units = savers_units
        self.start_time = start_time

    @property
    def end_time(self):
        """Gets the end_time of this SaversHistoryItem.  # noqa: E501

        Int64, The end time of bucket in unix timestamp  # noqa: E501

        :return: The end_time of this SaversHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """Sets the end_time of this SaversHistoryItem.

        Int64, The end time of bucket in unix timestamp  # noqa: E501

        :param end_time: The end_time of this SaversHistoryItem.  # noqa: E501
        :type: str
        """
        if end_time is None:
            raise ValueError("Invalid value for `end_time`, must not be `None`")  # noqa: E501

        self._end_time = end_time

    @property
    def savers_count(self):
        """Gets the savers_count of this SaversHistoryItem.  # noqa: E501

        Int64, Number of saver members in the pool at the end of the interval  # noqa: E501

        :return: The savers_count of this SaversHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._savers_count

    @savers_count.setter
    def savers_count(self, savers_count):
        """Sets the savers_count of this SaversHistoryItem.

        Int64, Number of saver members in the pool at the end of the interval  # noqa: E501

        :param savers_count: The savers_count of this SaversHistoryItem.  # noqa: E501
        :type: str
        """
        if savers_count is None:
            raise ValueError("Invalid value for `savers_count`, must not be `None`")  # noqa: E501

        self._savers_count = savers_count

    @property
    def savers_depth(self):
        """Gets the savers_depth of this SaversHistoryItem.  # noqa: E501

        Int64(e8), The depth in the savers vault at the end of the interval  # noqa: E501

        :return: The savers_depth of this SaversHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._savers_depth

    @savers_depth.setter
    def savers_depth(self, savers_depth):
        """Sets the savers_depth of this SaversHistoryItem.

        Int64(e8), The depth in the savers vault at the end of the interval  # noqa: E501

        :param savers_depth: The savers_depth of this SaversHistoryItem.  # noqa: E501
        :type: str
        """
        if savers_depth is None:
            raise ValueError("Invalid value for `savers_depth`, must not be `None`")  # noqa: E501

        self._savers_depth = savers_depth

    @property
    def savers_units(self):
        """Gets the savers_units of this SaversHistoryItem.  # noqa: E501

        Int64, Savers Units in the saver vault at the end of the interval   # noqa: E501

        :return: The savers_units of this SaversHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._savers_units

    @savers_units.setter
    def savers_units(self, savers_units):
        """Sets the savers_units of this SaversHistoryItem.

        Int64, Savers Units in the saver vault at the end of the interval   # noqa: E501

        :param savers_units: The savers_units of this SaversHistoryItem.  # noqa: E501
        :type: str
        """
        if savers_units is None:
            raise ValueError("Invalid value for `savers_units`, must not be `None`")  # noqa: E501

        self._savers_units = savers_units

    @property
    def start_time(self):
        """Gets the start_time of this SaversHistoryItem.  # noqa: E501

        Int64, The beginning time of bucket in unix timestamp  # noqa: E501

        :return: The start_time of this SaversHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this SaversHistoryItem.

        Int64, The beginning time of bucket in unix timestamp  # noqa: E501

        :param start_time: The start_time of this SaversHistoryItem.  # noqa: E501
        :type: str
        """
        if start_time is None:
            raise ValueError("Invalid value for `start_time`, must not be `None`")  # noqa: E501

        self._start_time = start_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SaversHistoryItem, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SaversHistoryItem):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Midgard Public API

    The Midgard Public API queries THORChain and any chains linked via the Bifröst and prepares information about the network to be readily available for public users. The API parses transaction event data from THORChain and stores them in a time-series database to make time-dependent queries easy. Midgard does not hold critical information. To interact with THORChain protocol, users should query THORNode directly.  # noqa: E501

    OpenAPI spec version: 2.20.1
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class TVLHistoryItem(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'end_time': 'str',
        'pools_depth': 'list[DepthHistoryItemPool]',
        'rune_price_usd': 'str',
        'start_time': 'str',
        'total_value_bonded': 'str',
        'total_value_locked': 'str',
        'total_value_pooled': 'str'
    }

    attribute_map = {
        'end_time': 'endTime',
        'pools_depth': 'poolsDepth',
        'rune_price_usd': 'runePriceUSD',
        'start_time': 'startTime',
        'total_value_bonded': 'totalValueBonded',
        'total_value_locked': 'totalValueLocked',
        'total_value_pooled': 'totalValuePooled'
    }

    def __init__(self, end_time=None, pools_depth=None, rune_price_usd=None, start_time=None, total_value_bonded=None, total_value_locked=None, total_value_pooled=None):  # noqa: E501
        """TVLHistoryItem - a model defined in Swagger"""  # noqa: E501
        self._end_time = None
        self._pools_depth = None
        self._rune_price_usd = None
        self._start_time = None
        self._total_value_bonded = None
        self._total_value_locked = None
        self._total_value_pooled = None
        self.discriminator = None
        self.end_time = end_time
        self.pools_depth = pools_depth
        self.rune_price_usd = rune_price_usd
        self.start_time = start_time
        if total_value_bonded is not None:
            self.total_value_bonded = total_value_bonded
        if total_value_locked is not None:
            self.total_value_locked = total_value_locked
        self.total_value_pooled = total_value_pooled

    @property
    def end_time(self):
        """Gets the end_time of this TVLHistoryItem.  # noqa: E501

        Int64, The end time of bucket in unix timestamp  # noqa: E501

        :return: The end_time of this TVLHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """Sets the end_time of this TVLHistoryItem.

        Int64, The end time of bucket in unix timestamp  # noqa: E501

        :param end_time: The end_time of this TVLHistoryItem.  # noqa: E501
        :type: str
        """
        if end_time is None:
            raise ValueError("Invalid value for `end_time`, must not be `None`")  # noqa: E501

        self._end_time = end_time

    @property
    def pools_depth(self):
        """Gets the pools_depth of this TVLHistoryItem.  # noqa: E501


        :return: The pools_depth of this TVLHistoryItem.  # noqa: E501
        :rtype: list[DepthHistoryItemPool]
        """
        return self._pools_depth

    @pools_depth.setter
    def pools_depth(self, pools_depth):
        """Sets the pools_depth of this TVLHistoryItem.


        :param pools_depth: The pools_depth of this TVLHistoryItem.  # noqa: E501
        :type: list[DepthHistoryItemPool]
        """
        if pools_depth is None:
            raise ValueError("Invalid value for `pools_depth`, must not be `None`")  # noqa: E501

        self._pools_depth = pools_depth

    @property
    def rune_price_usd(self):
        """Gets the rune_price_usd of this TVLHistoryItem.  # noqa: E501

        Float, the price of Rune based on the deepest USD pool at the end of the interval.   # noqa: E501

        :return: The rune_price_usd of this TVLHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._rune_price_usd

    @rune_price_usd.setter
    def rune_price_usd(self, rune_price_usd):
        """Sets the rune_price_usd of this TVLHistoryItem.

        Float, the price of Rune based on the deepest USD pool at the end of the interval.   # noqa: E501

        :param rune_price_usd: The rune_price_usd of this TVLHistoryItem.  # noqa: E501
        :type: str
        """
        if rune_price_usd is None:
            raise ValueError("Invalid value for `rune_price_usd`, must not be `None`")  # noqa: E501

        self._rune_price_usd = rune_price_usd

    @property
    def start_time(self):
        """Gets the start_time of this TVLHistoryItem.  # noqa: E501

        Int64, The beginning time of bucket in unix timestamp  # noqa: E501

        :return: The start_time of this TVLHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this TVLHistoryItem.

        Int64, The beginning time of bucket in unix timestamp  # noqa: E501

        :param start_time: The start_time of this TVLHistoryItem.  # noqa: E501
        :type: str
        """
        if start_time is None:
            raise ValueError("Invalid value for `start_time`, must not be `None`")  # noqa: E501

        self._start_time = start_time

    @property
    def total_value_bonded(self):
        """Gets the total_value_bonded of this TVLHistoryItem.  # noqa: E501

        Int64(e8), the total amount of bonds (both active and standby) at the end of the interval   # noqa: E501

        :return: The total_value_bonded of this TVLHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._total_value_bonded

    @total_value_bonded.setter
    def total_value_bonded(self, total_value_bonded):
        """Sets the total_value_bonded of this TVLHistoryItem.

        Int64(e8), the total amount of bonds (both active and standby) at the end of the interval   # noqa: E501

        :param total_value_bonded: The total_value_bonded of this TVLHistoryItem.  # noqa: E501
        :type: str
        """

        self._total_value_bonded = total_value_bonded

    @property
    def total_value_locked(self):
        """Gets the total_value_locked of this TVLHistoryItem.  # noqa: E501

        Int64(e8), total value locked in the chain (in rune) This equals `totalPooledValue + totalBondedValue`, as it combines the liquidity pools and bonds of the nodes.   # noqa: E501

        :return: The total_value_locked of this TVLHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._total_value_locked

    @total_value_locked.setter
    def total_value_locked(self, total_value_locked):
        """Sets the total_value_locked of this TVLHistoryItem.

        Int64(e8), total value locked in the chain (in rune) This equals `totalPooledValue + totalBondedValue`, as it combines the liquidity pools and bonds of the nodes.   # noqa: E501

        :param total_value_locked: The total_value_locked of this TVLHistoryItem.  # noqa: E501
        :type: str
        """

        self._total_value_locked = total_value_locked

    @property
    def total_value_pooled(self):
        """Gets the total_value_pooled of this TVLHistoryItem.  # noqa: E501

        Int64(e8) in rune, the total pooled value (both assets and rune) in all of the pools at the end of the interval. Note: this is twice the aggregate Rune depth of all pools.   # noqa: E501

        :return: The total_value_pooled of this TVLHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._total_value_pooled

    @total_value_pooled.setter
    def total_value_pooled(self, total_value_pooled):
        """Sets the total_value_pooled of this TVLHistoryItem.

        Int64(e8) in rune, the total pooled value (both assets and rune) in all of the pools at the end of the interval. Note: this is twice the aggregate Rune depth of all pools.   # noqa: E501

        :param total_value_pooled: The total_value_pooled of this TVLHistoryItem.  # noqa: E501
        :type: str
        """
        if total_value_pooled is None:
            raise ValueError("Invalid value for `total_value_pooled`, must not be `None`")  # noqa: E501

        self._total_value_pooled = total_value_pooled

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TVLHistoryItem, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TVLHistoryItem):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Midgard Public API

    The Midgard Public API queries THORChain and any chains linked via the Bifröst and prepares information about the network to be readily available for public users. The API parses transaction event data from THORChain and stores them in a time-series database to make time-dependent queries easy. Midgard does not hold critical information. To interact with THORChain protocol, users should query THORNode directly.  # noqa: E501

    OpenAPI spec version: 2.20.1
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import xchainpy2_midgard
from xchainpy2_midgard.models.earnings_history_intervals import EarningsHistoryIntervals  # noqa: E501
from xchainpy2_midgard.rest import ApiException


class TestEarningsHistoryIntervals(unittest.TestCase):
    """EarningsHistoryIntervals unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testEarningsHistoryIntervals(self):
        """Test EarningsHistoryIntervals"""
        # FIXME: construct object with mandatory attributes with example values
        # model = xchainpy2_midgard.models.earnings_history_intervals.EarningsHistoryIntervals()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Midgard Public API

    The Midgard Public API queries THORChain and any chains linked via the Bifröst and prepares information about the network to be readily available for public users. The API parses transaction event data from THORChain and stores them in a time-series database to make time-dependent queries easy. Midgard does not hold critical information. To interact with THORChain protocol, users should query THORNode directly.  # noqa: E501

    OpenAPI spec version: 2.20.1
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class DepthHistoryItem(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'asset_depth': 'str',
        'asset_price': 'str',
        'asset_price_usd': 'str',
        'end_time': 'str',
        'liquidity_units': 'str',
        'luvi': 'str',
        'members_count': 'str',
        'rune_depth': 'str',
        'start_time': 'str',
        'synth_supply': 'str',
        'synth_units': 'str',
        'units': 'str'
    }

    attribute_map = {
        'asset_depth': 'assetDepth',
        'asset_price': 'assetPrice',
        'asset_price_usd': 'assetPriceUSD',
        'end_time': 'endTime',
        'liquidity_units': 'liquidityUnits',
        'luvi': 'luvi',
        'members_count': 'membersCount',
        'rune_depth': 'runeDepth',
        'start_time': 'startTime',
        'synth_supply': 'synthSupply',
        'synth_units': 'synthUnits',
        'units': 'units'
    }

    def __init__(self, asset_depth=None, asset_price=None, asset_price_usd=None, end_time=None, liquidity_units=None, luvi=None, members_count=None, rune_depth=None, start_time=None, synth_supply=None, synth_units=None, units=None):  # noqa: E501
        """DepthHistoryItem - a model defined in Swagger"""  # noqa: E501
        self._asset_depth = None
        self._asset_price = None
        self._asset_price_usd = None
        self._end_time = None
        self._liquidity_units = None
        self._luvi = None
        self._members_count = None
        self._rune_depth = None
        self._start_time = None
        self._synth_supply = None
        self._synth_units = None
        self._units = None
        self.discriminator = None
        self.asset_depth = asset_depth
        self.asset_price = asset_price
        self.asset_price_usd = asset_price_usd
        self.end_time = end_time
        self.liquidity_units = liquidity_units
        self.luvi = luvi
        self.members_count = members_count
        self.rune_depth = rune_depth
        self.start_time = start_time
        self.synth_supply = synth_supply
        self.synth_units = synth_units
        self.units = units

    @property
    def asset_depth(self):
        """Gets the asset_depth of this DepthHistoryItem.  # noqa: E501

        Int64(e8), the amount of Asset in the pool at the end of the interval  # noqa: E501

        :return: The asset_depth of this DepthHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._asset_depth

    @asset_depth.setter
    def asset_depth(self, asset_depth):
        """Sets the asset_depth of this DepthHistoryItem.

        Int64(e8), the amount of Asset in the pool at the end of the interval  # noqa: E501

        :param asset_depth: The asset_depth of this DepthHistoryItem.  # noqa: E501
        :type: str
        """
        if asset_depth is None:
            raise ValueError("Invalid value for `asset_depth`, must not be `None`")  # noqa: E501

        self._asset_depth = asset_depth

    @property
    def asset_price(self):
        """Gets the asset_price of this DepthHistoryItem.  # noqa: E501

        Float, price of asset in rune. I.e. rune amount / asset amount  # noqa: E501

        :return: The asset_price of this DepthHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._asset_price

    @asset_price.setter
    def asset_price(self, asset_price):
        """Sets the asset_price of this DepthHistoryItem.

        Float, price of asset in rune. I.e. rune amount / asset amount  # noqa: E501

        :param asset_price: The asset_price of this DepthHistoryItem.  # noqa: E501
        :type: str
        """
        if asset_price is None:
            raise ValueError("Invalid value for `asset_price`, must not be `None`")  # noqa: E501

        self._asset_price = asset_price

    @property
    def asset_price_usd(self):
        """Gets the asset_price_usd of this DepthHistoryItem.  # noqa: E501

        Float, the price of asset in USD (based on the deepest USD pool).  # noqa: E501

        :return: The asset_price_usd of this DepthHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._asset_price_usd

    @asset_price_usd.setter
    def asset_price_usd(self, asset_price_usd):
        """Sets the asset_price_usd of this DepthHistoryItem.

        Float, the price of asset in USD (based on the deepest USD pool).  # noqa: E501

        :param asset_price_usd: The asset_price_usd of this DepthHistoryItem.  # noqa: E501
        :type: str
        """
        if asset_price_usd is None:
            raise ValueError("Invalid value for `asset_price_usd`, must not be `None`")  # noqa: E501

        self._asset_price_usd = asset_price_usd

    @property
    def end_time(self):
        """Gets the end_time of this DepthHistoryItem.  # noqa: E501

        Int64, The end time of bucket in unix timestamp  # noqa: E501

        :return: The end_time of this DepthHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """Sets the end_time of this DepthHistoryItem.

        Int64, The end time of bucket in unix timestamp  # noqa: E501

        :param end_time: The end_time of this DepthHistoryItem.  # noqa: E501
        :type: str
        """
        if end_time is None:
            raise ValueError("Invalid value for `end_time`, must not be `None`")  # noqa: E501

        self._end_time = end_time

    @property
    def liquidity_units(self):
        """Gets the liquidity_units of this DepthHistoryItem.  # noqa: E501

        Int64, Liquidity Units in the pool at the end of the interval  # noqa: E501

        :return: The liquidity_units of this DepthHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._liquidity_units

    @liquidity_units.setter
    def liquidity_units(self, liquidity_units):
        """Sets the liquidity_units of this DepthHistoryItem.

        Int64, Liquidity Units in the pool at the end of the interval  # noqa: E501

        :param liquidity_units: The liquidity_units of this DepthHistoryItem.  # noqa: E501
        :type: str
        """
        if liquidity_units is None:
            raise ValueError("Invalid value for `liquidity_units`, must not be `None`")  # noqa: E501

        self._liquidity_units = liquidity_units

    @property
    def luvi(self):
        """Gets the luvi of this DepthHistoryItem.  # noqa: E501

        Float, The liquidity unit value index. Sqrt(assetDepth * runeDepth)/liquidity units   # noqa: E501

        :return: The luvi of this DepthHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._luvi

    @luvi.setter
    def luvi(self, luvi):
        """Sets the luvi of this DepthHistoryItem.

        Float, The liquidity unit value index. Sqrt(assetDepth * runeDepth)/liquidity units   # noqa: E501

        :param luvi: The luvi of this DepthHistoryItem.  # noqa: E501
        :type: str
        """
        if luvi is None:
            raise ValueError("Invalid value for `luvi`, must not be `None`")  # noqa: E501

        self._luvi = luvi

    @property
    def members_count(self):
        """Gets the members_count of this DepthHistoryItem.  # noqa: E501

        Int64, Number of liquidity members in the pool at the end of the interval  # noqa: E501

        :return: The members_count of this DepthHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._members_count

    @members_count.setter
    def members_count(self, members_count):
        """Sets the members_count of this DepthHistoryItem.

        Int64, Number of liquidity members in the pool at the end of the interval  # noqa: E501

        :param members_count: The members_count of this DepthHistoryItem.  # noqa: E501
        :type: str
        """
        if members_count is None:
            raise ValueError("Invalid value for `members_count`, must not be `None`")  # noqa: E501

        self._members_count = members_count

    @property
    def rune_depth(self):
        """Gets the rune_depth of this DepthHistoryItem.  # noqa: E501

        Int64(e8), the amount of Rune in the pool at the end of the interval  # noqa: E501

        :return: The rune_depth of this DepthHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._rune_depth

    @rune_depth.setter
    def rune_depth(self, rune_depth):
        """Sets the rune_depth of this DepthHistoryItem.

        Int64(e8), the amount of Rune in the pool at the end of the interval  # noqa: E501

        :param rune_depth: The rune_depth of this DepthHistoryItem.  # noqa: E501
        :type: str
        """
        if rune_depth is None:
            raise ValueError("Invalid value for `rune_depth`, must not be `None`")  # noqa: E501

        self._rune_depth = rune_depth

    @property
    def start_time(self):
        """Gets the start_time of this DepthHistoryItem.  # noqa: E501

        Int64, The beginning time of bucket in unix timestamp  # noqa: E501

        :return: The start_time of this DepthHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this DepthHistoryItem.

        Int64, The beginning time of bucket in unix timestamp  # noqa: E501

        :param start_time: The start_time of this DepthHistoryItem.  # noqa: E501
        :type: str
        """
        if start_time is None:
            raise ValueError("Invalid value for `start_time`, must not be `None`")  # noqa: E501

        self._start_time = start_time

    @property
    def synth_supply(self):
        """Gets the synth_supply of this DepthHistoryItem.  # noqa: E501

        Int64, Synth supply in the pool at the end of the interval  # noqa: E501

        :return: The synth_supply of this DepthHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._synth_supply

    @synth_supply.setter
    def synth_supply(self, synth_supply):
        """Sets the synth_supply of this DepthHistoryItem.

        Int64, Synth supply in the pool at the end of the interval  # noqa: E501

        :param synth_supply: The synth_supply of this DepthHistoryItem.  # noqa: E501
        :type: str
        """
        if synth_supply is None:
            raise ValueError("Invalid value for `synth_supply`, must not be `None`")  # noqa: E501

        self._synth_supply = synth_supply

    @property
    def synth_units(self):
        """Gets the synth_units of this DepthHistoryItem.  # noqa: E501

        Int64, Synth Units in the pool at the end of the interval  # noqa: E501

        :return: The synth_units of this DepthHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._synth_units

    @synth_units.setter
    def synth_units(self, synth_units):
        """Sets the synth_units of this DepthHistoryItem.

        Int64, Synth Units in the pool at the end of the interval  # noqa: E501

        :param synth_units: The synth_units of this DepthHistoryItem.  # noqa: E501
        :type: str
        """
        if synth_units is None:
            raise ValueError("Invalid value for `synth_units`, must not be `None`")  # noqa: E501

        self._synth_units = synth_units

    @property
    def units(self):
        """Gets the units of this DepthHistoryItem.  # noqa: E501

        Int64, Total Units (synthUnits + liquidityUnits) in the pool at the end of the interval   # noqa: E501

        :return: The units of this DepthHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._units

    @units.setter
    def units(self, units):
        """Sets the units of this DepthHistoryItem.

        Int64, Total Units (synthUnits + liquidityUnits) in the pool at the end of the interval   # noqa: E501

        :param units: The units of this DepthHistoryItem.  # noqa: E501
        :type: str
        """
        if units is None:
            raise ValueError("Invalid value for `units`, must not be `None`")  # noqa: E501

        self._units = units

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DepthHistoryItem, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DepthHistoryItem):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Midgard Public API

    The Midgard Public API queries THORChain and any chains linked via the Bifröst and prepares information about the network to be readily available for public users. The API parses transaction event data from THORChain and stores them in a time-series database to make time-dependent queries easy. Midgard does not hold critical information. To interact with THORChain protocol, users should query THORNode directly.  # noqa: E501

    OpenAPI spec version: 2.20.1
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class WithdrawMetadata(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'asymmetry': 'str',
        'basis_points': 'str',
        'impermanent_loss_protection': 'str',
        'liquidity_units': 'str',
        'memo': 'str',
        'network_fees': 'NetworkFees'
    }

    attribute_map = {
        'asymmetry': 'asymmetry',
        'basis_points': 'basisPoints',
        'impermanent_loss_protection': 'impermanentLossProtection',
        'liquidity_units': 'liquidityUnits',
        'memo': 'memo',
        'network_fees': 'networkFees'
    }

    def __init__(self, asymmetry=None, basis_points=None, impermanent_loss_protection=None, liquidity_units=None, memo=None, network_fees=None):  # noqa: E501
        """WithdrawMetadata - a model defined in Swagger"""  # noqa: E501
        self._asymmetry = None
        self._basis_points = None
        self._impermanent_loss_protection = None
        self._liquidity_units = None
        self._memo = None
        self._network_fees = None
        self.discriminator = None
        self.asymmetry = asymmetry
        self.basis_points = basis_points
        self.impermanent_loss_protection = impermanent_loss_protection
        self.liquidity_units = liquidity_units
        self.memo = memo
        self.network_fees = network_fees

    @property
    def asymmetry(self):
        """Gets the asymmetry of this WithdrawMetadata.  # noqa: E501

        Decimal (-1.0 <=> 1.0), indicates how assymetrical the withdrawal was. 0 means totally symetrical   # noqa: E501

        :return: The asymmetry of this WithdrawMetadata.  # noqa: E501
        :rtype: str
        """
        return self._asymmetry

    @asymmetry.setter
    def asymmetry(self, asymmetry):
        """Sets the asymmetry of this WithdrawMetadata.

        Decimal (-1.0 <=> 1.0), indicates how assymetrical the withdrawal was. 0 means totally symetrical   # noqa: E501

        :param asymmetry: The asymmetry of this WithdrawMetadata.  # noqa: E501
        :type: str
        """
        if asymmetry is None:
            raise ValueError("Invalid value for `asymmetry`, must not be `None`")  # noqa: E501

        self._asymmetry = asymmetry

    @property
    def basis_points(self):
        """Gets the basis_points of this WithdrawMetadata.  # noqa: E501

        Int64 (Basis points, 0-10000, where 10000=100%), percentage of total pool ownership withdrawn   # noqa: E501

        :return: The basis_points of this WithdrawMetadata.  # noqa: E501
        :rtype: str
        """
        return self._basis_points

    @basis_points.setter
    def basis_points(self, basis_points):
        """Sets the basis_points of this WithdrawMetadata.

        Int64 (Basis points, 0-10000, where 10000=100%), percentage of total pool ownership withdrawn   # noqa: E501

        :param basis_points: The basis_points of this WithdrawMetadata.  # noqa: E501
        :type: str
        """
        if basis_points is None:
            raise ValueError("Invalid value for `basis_points`, must not be `None`")  # noqa: E501

        self._basis_points = basis_points

    @property
    def impermanent_loss_protection(self):
        """Gets the impermanent_loss_protection of this WithdrawMetadata.  # noqa: E501

        Int64, additional Rune payed out because of impermanent loss protection  # noqa: E501

        :return: The impermanent_loss_protection of this WithdrawMetadata.  # noqa: E501
        :rtype: str
        """
        return self._impermanent_loss_protection

    @impermanent_loss_protection.setter
    def impermanent_loss_protection(self, impermanent_loss_protection):
        """Sets the impermanent_loss_protection of this WithdrawMetadata.

        Int64, additional Rune payed out because of impermanent loss protection  # noqa: E501

        :param impermanent_loss_protection: The impermanent_loss_protection of this WithdrawMetadata.  # noqa: E501
        :type: str
        """
        if impermanent_loss_protection is None:
            raise ValueError("Invalid value for `impermanent_loss_protection`, must not be `None`")  # noqa: E501

        self._impermanent_loss_protection = impermanent_loss_protection

    @property
    def liquidity_units(self):
        """Gets the liquidity_units of this WithdrawMetadata.  # noqa: E501

        Int64, amount of liquidity units removed from the member as result of the withdrawal   # noqa: E501

        :return: The liquidity_units of this WithdrawMetadata.  # noqa: E501
        :rtype: str
        """
        return self._liquidity_units

    @liquidity_units.setter
    def liquidity_units(self, liquidity_units):
        """Sets the liquidity_units of this WithdrawMetadata.

        Int64, amount of liquidity units removed from the member as result of the withdrawal   # noqa: E501

        :param liquidity_units: The liquidity_units of this WithdrawMetadata.  # noqa: E501
        :type: str
        """
        if liquidity_units is None:
            raise ValueError("Invalid value for `liquidity_units`, must not be `None`")  # noqa: E501

        self._liquidity_units = liquidity_units

    @property
    def memo(self):
        """Gets the memo of this WithdrawMetadata.  # noqa: E501

        Transaction memo of the withdraw action  # noqa: E501

        :return: The memo of this WithdrawMetadata.  # noqa: E501
        :rtype: str
        """
        return self._memo

    @memo.setter
    def memo(self, memo):
        """Sets the memo of this WithdrawMetadata.

        Transaction memo of the withdraw action  # noqa: E501

        :param memo: The memo of this WithdrawMetadata.  # noqa: E501
        :type: str
        """
        if memo is None:
            raise ValueError("Invalid value for `memo`, must not be `None`")  # noqa: E501

        self._memo = memo

    @property
    def network_fees(self):
        """Gets the network_fees of this WithdrawMetadata.  # noqa: E501


        :return: The network_fees of this WithdrawMetadata.  # noqa: E501
        :rtype: NetworkFees
        """
        return self._network_fees

    @network_fees.setter
    def network_fees(self, network_fees):
        """Sets the network_fees of this WithdrawMetadata.


        :param network_fees: The network_fees of this WithdrawMetadata.  # noqa: E501
        :type: NetworkFees
        """
        if network_fees is None:
            raise ValueError("Invalid value for `network_fees`, must not be `None`")  # noqa: E501

        self._network_fees = network_fees

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(WithdrawMetadata, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WithdrawMetadata):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Midgard Public API

    The Midgard Public API queries THORChain and any chains linked via the Bifröst and prepares information about the network to be readily available for public users. The API parses transaction event data from THORChain and stores them in a time-series database to make time-dependent queries easy. Midgard does not hold critical information. To interact with THORChain protocol, users should query THORNode directly.  # noqa: E501

    OpenAPI spec version: 2.20.1
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class DepthHistoryMeta(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'end_asset_depth': 'str',
        'end_lp_units': 'str',
        'end_member_count': 'str',
        'end_rune_depth': 'str',
        'end_synth_units': 'str',
        'end_time': 'str',
        'luvi_increase': 'str',
        'price_shift_loss': 'str',
        'start_asset_depth': 'str',
        'start_lp_units': 'str',
        'start_member_count': 'str',
        'start_rune_depth': 'str',
        'start_synth_units': 'str',
        'start_time': 'str'
    }

    attribute_map = {
        'end_asset_depth': 'endAssetDepth',
        'end_lp_units': 'endLPUnits',
        'end_member_count': 'endMemberCount',
        'end_rune_depth': 'endRuneDepth',
        'end_synth_units': 'endSynthUnits',
        'end_time': 'endTime',
        'luvi_increase': 'luviIncrease',
        'price_shift_loss': 'priceShiftLoss',
        'start_asset_depth': 'startAssetDepth',
        'start_lp_units': 'startLPUnits',
        'start_member_count': 'startMemberCount',
        'start_rune_depth': 'startRuneDepth',
        'start_synth_units': 'startSynthUnits',
        'start_time': 'startTime'
    }

    def __init__(self, end_asset_depth=None, end_lp_units=None, end_member_count=None, end_rune_depth=None, end_synth_units=None, end_time=None, luvi_increase=None, price_shift_loss=None, start_asset_depth=None, start_lp_units=None, start_member_count=None, start_rune_depth=None, start_synth_units=None, start_time=None):  # noqa: E501
        """DepthHistoryMeta - a model defined in Swagger"""  # noqa: E501
        self._end_asset_depth = None
        self._end_lp_units = None
        self._end_member_count = None
        self._end_rune_depth = None
        self._end_synth_units = None
        self._end_time = None
        self._luvi_increase = None
        self._price_shift_loss = None
        self._start_asset_depth = None
        self._start_lp_units = None
        self._start_member_count = None
        self._start_rune_depth = None
        self._start_synth_units = None
        self._start_time = None
        self.discriminator = None
        self.end_asset_depth = end_asset_depth
        self.end_lp_units = end_lp_units
        self.end_member_count = end_member_count
        self.end_rune_depth = end_rune_depth
        self.end_synth_units = end_synth_units
        self.end_time = end_time
        self.luvi_increase = luvi_increase
        self.price_shift_loss = price_shift_loss
        self.start_asset_depth = start_asset_depth
        self.start_lp_units = start_lp_units
        self.start_member_count = start_member_count
        self.start_rune_depth = start_rune_depth
        self.start_synth_units = start_synth_units
        self.start_time = start_time

    @property
    def end_asset_depth(self):
        """Gets the end_asset_depth of this DepthHistoryMeta.  # noqa: E501

        Int64(e8), the amount of Asset in the pool at the end of the interval at time endTime   # noqa: E501

        :return: The end_asset_depth of this DepthHistoryMeta.  # noqa: E501
        :rtype: str
        """
        return self._end_asset_depth

    @end_asset_depth.setter
    def end_asset_depth(self, end_asset_depth):
        """Sets the end_asset_depth of this DepthHistoryMeta.

        Int64(e8), the amount of Asset in the pool at the end of the interval at time endTime   # noqa: E501

        :param end_asset_depth: The end_asset_depth of this DepthHistoryMeta.  # noqa: E501
        :type: str
        """
        if end_asset_depth is None:
            raise ValueError("Invalid value for `end_asset_depth`, must not be `None`")  # noqa: E501

        self._end_asset_depth = end_asset_depth

    @property
    def end_lp_units(self):
        """Gets the end_lp_units of this DepthHistoryMeta.  # noqa: E501

        Int64, Liquidity Units in the pool at the end of the interval at time endTime  # noqa: E501

        :return: The end_lp_units of this DepthHistoryMeta.  # noqa: E501
        :rtype: str
        """
        return self._end_lp_units

    @end_lp_units.setter
    def end_lp_units(self, end_lp_units):
        """Sets the end_lp_units of this DepthHistoryMeta.

        Int64, Liquidity Units in the pool at the end of the interval at time endTime  # noqa: E501

        :param end_lp_units: The end_lp_units of this DepthHistoryMeta.  # noqa: E501
        :type: str
        """
        if end_lp_units is None:
            raise ValueError("Invalid value for `end_lp_units`, must not be `None`")  # noqa: E501

        self._end_lp_units = end_lp_units

    @property
    def end_member_count(self):
        """Gets the end_member_count of this DepthHistoryMeta.  # noqa: E501

        Int64, Number of liquidity members in the pool at the end of the interval at time endTime  # noqa: E501

        :return: The end_member_count of this DepthHistoryMeta.  # noqa: E501
        :rtype: str
        """
        return self._end_member_count

    @end_member_count.setter
    def end_member_count(self, end_member_count):
        """Sets the end_member_count of this DepthHistoryMeta.

        Int64, Number of liquidity members in the pool at the end of the interval at time endTime  # noqa: E501

        :param end_member_count: The end_member_count of this DepthHistoryMeta.  # noqa: E501
        :type: str
        """
        if end_member_count is None:
            raise ValueError("Invalid value for `end_member_count`, must not be `None`")  # noqa: E501

        self._end_member_count = end_member_count

    @property
    def end_rune_depth(self):
        """Gets the end_rune_depth of this DepthHistoryMeta.  # noqa: E501

        Int64(e8), the amount of Rune in the pool at the end of the interval at time endTime   # noqa: E501

        :return: The end_rune_depth of this DepthHistoryMeta.  # noqa: E501
        :rtype: str
        """
        return self._end_rune_depth

    @end_rune_depth.setter
    def end_rune_depth(self, end_rune_depth):
        """Sets the end_rune_depth of this DepthHistoryMeta.

        Int64(e8), the amount of Rune in the pool at the end of the interval at time endTime   # noqa: E501

        :param end_rune_depth: The end_rune_depth of this DepthHistoryMeta.  # noqa: E501
        :type: str
        """
        if end_rune_depth is None:
            raise ValueError("Invalid value for `end_rune_depth`, must not be `None`")  # noqa: E501

        self._end_rune_depth = end_rune_depth

    @property
    def end_synth_units(self):
        """Gets the end_synth_units of this DepthHistoryMeta.  # noqa: E501

        Int64, Synth Units in the pool at the end of the interval at time endTime  # noqa: E501

        :return: The end_synth_units of this DepthHistoryMeta.  # noqa: E501
        :rtype: str
        """
        return self._end_synth_units

    @end_synth_units.setter
    def end_synth_units(self, end_synth_units):
        """Sets the end_synth_units of this DepthHistoryMeta.

        Int64, Synth Units in the pool at the end of the interval at time endTime  # noqa: E501

        :param end_synth_units: The end_synth_units of this DepthHistoryMeta.  # noqa: E501
        :type: str
        """
        if end_synth_units is None:
            raise ValueError("Invalid value for `end_synth_units`, must not be `None`")  # noqa: E501

        self._end_synth_units = end_synth_units

    @property
    def end_time(self):
        """Gets the end_time of this DepthHistoryMeta.  # noqa: E501

        Int64, The end time of bucket in unix timestamp  # noqa: E501

        :return: The end_time of this DepthHistoryMeta.  # noqa: E501
        :rtype: str
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """Sets the end_time of this DepthHistoryMeta.

        Int64, The end time of bucket in unix timestamp  # noqa: E501

        :param end_time: The end_time of this DepthHistoryMeta.  # noqa: E501
        :type: str
        """
        if end_time is None:
            raise ValueError("Invalid value for `end_time`, must not be `None`")  # noqa: E501

        self._end_time = end_time

    @property
    def luvi_increase(self):
        """Gets the luvi_increase of this DepthHistoryMeta.  # noqa: E501

        Float, The liquidity unit value index increase between startTime and endTime   # noqa: E501

        :return: The luvi_increase of this DepthHistoryMeta.  # noqa: E501
        :rtype: str
        """
        return self._luvi_increase

    @luvi_increase.setter
    def luvi_increase(self, luvi_increase):
        """Sets the luvi_increase of this DepthHistoryMeta.

        Float, The liquidity unit value index increase between startTime and endTime   # noqa: E501

        :param luvi_increase: The luvi_increase of this DepthHistoryMeta.  # noqa: E501
        :type: str
        """
        if luvi_increase is None:
            raise ValueError("Invalid value for `luvi_increase`, must not be `None`")  # noqa: E501

        self._luvi_increase = luvi_increase

    @property
    def price_shift_loss(self):
        """Gets the price_shift_loss of this DepthHistoryMeta.  # noqa: E501

        Float, The impermanent loss between the first and last depth item  # noqa: E501

        :return: The price_shift_loss of this DepthHistoryMeta.  # noqa: E501
        :rtype: str
        """
        return self._price_shift_loss

    @price_shift_loss.setter
    def price_shift_loss(self, price_shift_loss):
        """Sets the price_shift_loss of this DepthHistoryMeta.

        Float, The impermanent loss between the first and last depth item  # noqa: E501

        :param price_shift_loss: The price_shift_loss of this DepthHistoryMeta.  # noqa: E501
        :type: str
        """
        if price_shift_loss is None:
            raise ValueError("Invalid value for `price_shift_loss`, must not be `None`")  # noqa: E501

        self._price_shift_loss = price_shift_loss

    @property
    def start_asset_depth(self):
        """Gets the start_asset_depth of this DepthHistoryMeta.  # noqa: E501

        Int64(e8), the amount of Asset in the pool at the start of the interval at time startTime   # noqa: E501

        :return: The start_asset_depth of this DepthHistoryMeta.  # noqa: E501
        :rtype: str
        """
        return self._start_asset_depth

    @start_asset_depth.setter
    def start_asset_depth(self, start_asset_depth):
        """Sets the start_asset_depth of this DepthHistoryMeta.

        Int64(e8), the amount of Asset in the pool at the start of the interval at time startTime   # noqa: E501

        :param start_asset_depth: The start_asset_depth of this DepthHistoryMeta.  # noqa: E501
        :type: str
        """
        if start_asset_depth is None:
            raise ValueError("Invalid value for `start_asset_depth`, must not be `None`")  # noqa: E501

        self._start_asset_depth = start_asset_depth

    @property
    def start_lp_units(self):
        """Gets the start_lp_units of this DepthHistoryMeta.  # noqa: E501

        Int64, Liquidity Units in the pool at the start of the interval at time startTime   # noqa: E501

        :return: The start_lp_units of this DepthHistoryMeta.  # noqa: E501
        :rtype: str
        """
        return self._start_lp_units

    @start_lp_units.setter
    def start_lp_units(self, start_lp_units):
        """Sets the start_lp_units of this DepthHistoryMeta.

        Int64, Liquidity Units in the pool at the start of the interval at time startTime   # noqa: E501

        :param start_lp_units: The start_lp_units of this DepthHistoryMeta.  # noqa: E501
        :type: str
        """
        if start_lp_units is None:
            raise ValueError("Invalid value for `start_lp_units`, must not be `None`")  # noqa: E501

        self._start_lp_units = start_lp_units

    @property
    def start_member_count(self):
        """Gets the start_member_count of this DepthHistoryMeta.  # noqa: E501

        Int64, Number of liquidity member in the pool at the start of the interval at time startTime   # noqa: E501

        :return: The start_member_count of this DepthHistoryMeta.  # noqa: E501
        :rtype: str
        """
        return self._start_member_count

    @start_member_count.setter
    def start_member_count(self, start_member_count):
        """Sets the start_member_count of this DepthHistoryMeta.

        Int64, Number of liquidity member in the pool at the start of the interval at time startTime   # noqa: E501

        :param start_member_count: The start_member_count of this DepthHistoryMeta.  # noqa: E501
        :type: str
        """
        if start_member_count is None:
            raise ValueError("Invalid value for `start_member_count`, must not be `None`")  # noqa: E501

        self._start_member_count = start_member_count

    @property
    def start_rune_depth(self):
        """Gets the start_rune_depth of this DepthHistoryMeta.  # noqa: E501

        Int64(e8), the amount of Rune in the pool at the start of the interval at time startTime   # noqa: E501

        :return: The start_rune_depth of this DepthHistoryMeta.  # noqa: E501
        :rtype: str
        """
        return self._start_rune_depth

    @start_rune_depth.setter
    def start_rune_depth(self, start_rune_depth):
        """Sets the start_rune_depth of this DepthHistoryMeta.

        Int64(e8), the amount of Rune in the pool at the start of the interval at time startTime   # noqa: E501

        :param start_rune_depth: The start_rune_depth of this DepthHistoryMeta.  # noqa: E501
        :type: str
        """
        if start_rune_depth is None:
            raise ValueError("Invalid value for `start_rune_depth`, must not be `None`")  # noqa: E501

        self._start_rune_depth = start_rune_depth

    @property
    def start_synth_units(self):
        """Gets the start_synth_units of this DepthHistoryMeta.  # noqa: E501

        Int64, Synth Units in the pool at the start of the interval at time startTime   # noqa: E501

        :return: The start_synth_units of this DepthHistoryMeta.  # noqa: E501
        :rtype: str
        """
        return self._start_synth_units

    @start_synth_units.setter
    def start_synth_units(self, start_synth_units):
        """Sets the start_synth_units of this DepthHistoryMeta.

        Int64, Synth Units in the pool at the start of the interval at time startTime   # noqa: E501

        :param start_synth_units: The start_synth_units of this DepthHistoryMeta.  # noqa: E501
        :type: str
        """
        if start_synth_units is None:
            raise ValueError("Invalid value for `start_synth_units`, must not be `None`")  # noqa: E501

        self._start_synth_units = start_synth_units

    @property
    def start_time(self):
        """Gets the start_time of this DepthHistoryMeta.  # noqa: E501

        Int64, The beginning time of bucket in unix timestamp  # noqa: E501

        :return: The start_time of this DepthHistoryMeta.  # noqa: E501
        :rtype: str
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this DepthHistoryMeta.

        Int64, The beginning time of bucket in unix timestamp  # noqa: E501

        :param start_time: The start_time of this DepthHistoryMeta.  # noqa: E501
        :type: str
        """
        if start_time is None:
            raise ValueError("Invalid value for `start_time`, must not be `None`")  # noqa: E501

        self._start_time = start_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DepthHistoryMeta, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DepthHistoryMeta):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Midgard Public API

    The Midgard Public API queries THORChain and any chains linked via the Bifröst and prepares information about the network to be readily available for public users. The API parses transaction event data from THORChain and stores them in a time-series database to make time-dependent queries easy. Midgard does not hold critical information. To interact with THORChain protocol, users should query THORNode directly.  # noqa: E501

    OpenAPI spec version: 2.20.1
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import io
import json
import logging
import re
import ssl

import aiohttp
import certifi
# python 2 and python 3 compatibility library
from six.moves.urllib.parse import urlencode

logger = logging.getLogger(__name__)


class RESTResponse(io.IOBase):

    def __init__(self, resp, data):
        self.aiohttp_response = resp
        self.status = resp.status
        self.reason = resp.reason
        self.data = data

    def getheaders(self):
        """Returns a CIMultiDictProxy of the response headers."""
        return self.aiohttp_response.headers

    def getheader(self, name, default=None):
        """Returns a given response header."""
        return self.aiohttp_response.headers.get(name, default)


class RESTClientObject(object):

    def __init__(self, configuration, pools_size=4, maxsize=4):
        # maxsize is number of requests to host that are allowed in parallel
        # ca_certs vs cert_file vs key_file
        # http://stackoverflow.com/a/23957365/2985775

        # ca_certs
        if configuration.ssl_ca_cert:
            ca_certs = configuration.ssl_ca_cert
        else:
            # if not set certificate file, use Mozilla's root certificates.
            ca_certs = certifi.where()

        ssl_context = ssl.create_default_context(cafile=ca_certs)
        if configuration.cert_file:
            ssl_context.load_cert_chain(
                configuration.cert_file, keyfile=configuration.key_file
            )

        connector = aiohttp.TCPConnector(
            limit=maxsize,
            ssl_context=ssl_context,
            verify_ssl=configuration.verify_ssl
        )

        # https pool manager
        if configuration.proxy:
            self.pool_manager = aiohttp.ClientSession(
                connector=connector,
                proxy=configuration.proxy
            )
        else:
            self.pool_manager = aiohttp.ClientSession(
                connector=connector
            )

    async def request(self, method, url, query_params=None, headers=None,
                      body=None, post_params=None, _preload_content=True,
                      _request_timeout=None):
        """Execute request

        :param method: http request method
        :param url: http request url
        :param query_params: query parameters in the url
        :param headers: http request headers
        :param body: request json body, for `application/json`
        :param post_params: request post parameters,
                            `application/x-www-form-urlencoded`
                            and `multipart/form-data`
        :param _preload_content: this is a non-applicable field for
                                 the AiohttpClient.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        """
        method = method.upper()
        assert method in ['GET', 'HEAD', 'DELETE', 'POST', 'PUT',
                          'PATCH', 'OPTIONS']

        if post_params and body:
            raise ValueError(
                "body parameter cannot be used with post_params parameter."
            )

        post_params = post_params or {}
        headers = headers or {}
        timeout = _request_timeout or 5 * 60

        if 'Content-Type' not in headers:
            headers['Content-Type'] = 'application/json'

        args = {
            "method": method,
            "url": url,
            "timeout": timeout,
            "headers": headers
        }

        if query_params:
            args["url"] += '?' + urlencode(query_params)

        # For `POST`, `PUT`, `PATCH`, `OPTIONS`, `DELETE`
        if method in ['POST', 'PUT', 'PATCH', 'OPTIONS', 'DELETE']:
            if re.search('json', headers['Content-Type'], re.IGNORECASE):
                if body is not None:
                    body = json.dumps(body)
                args["data"] = body
            elif headers['Content-Type'] == 'application/x-www-form-urlencoded':  # noqa: E501
                args["data"] = aiohttp.FormData(post_params)
            elif headers['Content-Type'] == 'multipart/form-data':
                # must del headers['Content-Type'], or the correct
                # Content-Type which generated by aiohttp
                del headers['Content-Type']
                data = aiohttp.FormData()
                for param in post_params:
                    k, v = param
                    if isinstance(v, tuple) and len(v) == 3:
                        data.add_field(k,
                                       value=v[1],
                                       filename=v[0],
                                       content_type=v[2])
                    else:
                        data.add_field(k, v)
                args["data"] = data

            # Pass a `bytes` parameter directly in the body to support
            # other content types than Json when `body` argument is provided
            # in serialized form
            elif isinstance(body, bytes):
                args["data"] = body
            else:
                # Cannot generate the request from given parameters
                msg = """Cannot prepare a request message for provided
                         arguments. Please check that your arguments match
                         declared content type."""
                raise ApiException(status=0, reason=msg)

        async with self.pool_manager.request(**args) as r:
            data = await r.text()
            r = RESTResponse(r, data)

        # log response body
        logger.debug("response body: %s", r.data)

        if not 200 <= r.status <= 299:
            raise ApiException(http_resp=r)

        return r

    async def GET(self, url, headers=None, query_params=None,
                  _preload_content=True, _request_timeout=None):
        return (await self.request("GET", url,
                                   headers=headers,
                                   _preload_content=_preload_content,
                                   _request_timeout=_request_timeout,
                                   query_params=query_params))

    async def HEAD(self, url, headers=None, query_params=None,
                   _preload_content=True, _request_timeout=None):
        return (await self.request("HEAD", url,
                                   headers=headers,
                                   _preload_content=_preload_content,
                                   _request_timeout=_request_timeout,
                                   query_params=query_params))

    async def OPTIONS(self, url, headers=None, query_params=None,
                      post_params=None, body=None, _preload_content=True,
                      _request_timeout=None):
        return (await self.request("OPTIONS", url,
                                   headers=headers,
                                   query_params=query_params,
                                   post_params=post_params,
                                   _preload_content=_preload_content,
                                   _request_timeout=_request_timeout,
                                   body=body))

    async def DELETE(self, url, headers=None, query_params=None, body=None,
                     _preload_content=True, _request_timeout=None):
        return (await self.request("DELETE", url,
                                   headers=headers,
                                   query_params=query_params,
                                   _preload_content=_preload_content,
                                   _request_timeout=_request_timeout,
                                   body=body))

    async def POST(self, url, headers=None, query_params=None,
                   post_params=None, body=None, _preload_content=True,
                   _request_timeout=None):
        return (await self.request("POST", url,
                                   headers=headers,
                                   query_params=query_params,
                                   post_params=post_params,
                                   _preload_content=_preload_content,
                                   _request_timeout=_request_timeout,
                                   body=body))

    async def PUT(self, url, headers=None, query_params=None, post_params=None,
                  body=None, _preload_content=True, _request_timeout=None):
        return (await self.request("PUT", url,
                                   headers=headers,
                                   query_params=query_params,
                                   post_params=post_params,
                                   _preload_content=_preload_content,
                                   _request_timeout=_request_timeout,
                                   body=body))

    async def PATCH(self, url, headers=None, query_params=None,
                    post_params=None, body=None, _preload_content=True,
                    _request_timeout=None):
        return (await self.request("PATCH", url,
                                   headers=headers,
                                   query_params=query_params,
                                   post_params=post_params,
                                   _preload_content=_preload_content,
                                   _request_timeout=_request_timeout,
                                   body=body))


class ApiException(Exception):

    def __init__(self, status=None, reason=None, http_resp=None):
        if http_resp:
            self.status = http_resp.status
            self.reason = http_resp.reason
            self.body = http_resp.data
            self.headers = http_resp.getheaders()
        else:
            self.status = status
            self.reason = reason
            self.body = None
            self.headers = None

    def __str__(self):
        """Custom error messages for exception"""
        error_message = "({0})\nReason: {1}\n".format(self.status, self.reason)
        if self.headers:
            error_message += "HTTP response headers: {0}\n".format(
                self.headers)

        if self.body:
            error_message += "HTTP response body: {0}\n".format(self.body)

        return error_message



# coding: utf-8

"""
    Midgard Public API

    The Midgard Public API queries THORChain and any chains linked via the Bifröst and prepares information about the network to be readily available for public users. The API parses transaction event data from THORChain and stores them in a time-series database to make time-dependent queries easy. Midgard does not hold critical information. To interact with THORChain protocol, users should query THORNode directly.  # noqa: E501

    OpenAPI spec version: 2.20.1
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import xchainpy2_midgard
from xchainpy2_midgard.api.default_api import DefaultApi  # noqa: E501
from xchainpy2_midgard.rest import ApiException


class TestDefaultApi(unittest.TestCase):
    """DefaultApi unit test stubs"""

    def setUp(self):
        self.api = DefaultApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_actions(self):
        """Test case for get_actions

        Actions List  # noqa: E501
        """
        pass

    def test_get_balance(self):
        """Test case for get_balance

        Current balance for an address  # noqa: E501
        """
        pass

    def test_get_borrower_detail(self):
        """Test case for get_borrower_detail

        Borrower Details  # noqa: E501
        """
        pass

    def test_get_borrowers_addresses(self):
        """Test case for get_borrowers_addresses

        Borrowers List  # noqa: E501
        """
        pass

    def test_get_churns(self):
        """Test case for get_churns

        Churns List  # noqa: E501
        """
        pass

    def test_get_depth_history(self):
        """Test case for get_depth_history

        Depth and Price History  # noqa: E501
        """
        pass

    def test_get_earnings_history(self):
        """Test case for get_earnings_history

        Earnings History  # noqa: E501
        """
        pass

    def test_get_health(self):
        """Test case for get_health

        Health Info  # noqa: E501
        """
        pass

    def test_get_known_pools(self):
        """Test case for get_known_pools

        Known Pools List  # noqa: E501
        """
        pass

    def test_get_liquidity_history(self):
        """Test case for get_liquidity_history

        Liquidity Changes History  # noqa: E501
        """
        pass

    def test_get_member_detail(self):
        """Test case for get_member_detail

        Member Details  # noqa: E501
        """
        pass

    def test_get_members_adresses(self):
        """Test case for get_members_adresses

        Members List  # noqa: E501
        """
        pass

    def test_get_network_data(self):
        """Test case for get_network_data

        Network Data  # noqa: E501
        """
        pass

    def test_get_nodes(self):
        """Test case for get_nodes

        Nodes List  # noqa: E501
        """
        pass

    def test_get_pool(self):
        """Test case for get_pool

        Details of a Pool  # noqa: E501
        """
        pass

    def test_get_pool_stats(self):
        """Test case for get_pool_stats

        Pool Statistics  # noqa: E501
        """
        pass

    def test_get_pools(self):
        """Test case for get_pools

        Pools List  # noqa: E501
        """
        pass

    def test_get_saver_detail(self):
        """Test case for get_saver_detail

        Saver Details  # noqa: E501
        """
        pass

    def test_get_savers_history(self):
        """Test case for get_savers_history

        Savers Units and Depth History  # noqa: E501
        """
        pass

    def test_get_stats(self):
        """Test case for get_stats

        Global Stats  # noqa: E501
        """
        pass

    def test_get_swap_history(self):
        """Test case for get_swap_history

        Swaps History  # noqa: E501
        """
        pass

    def test_get_thor_name_detail(self):
        """Test case for get_thor_name_detail

        THORName Details  # noqa: E501
        """
        pass

    def test_get_thor_names_by_address(self):
        """Test case for get_thor_names_by_address

        Gives a list of THORNames by reverse lookup  # noqa: E501
        """
        pass

    def test_get_thor_names_owner_by_address(self):
        """Test case for get_thor_names_owner_by_address

        THORName owner  # noqa: E501
        """
        pass

    def test_get_tvl_history(self):
        """Test case for get_tvl_history

        Total Value Locked History  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Midgard Public API

    The Midgard Public API queries THORChain and any chains linked via the Bifröst and prepares information about the network to be readily available for public users. The API parses transaction event data from THORChain and stores them in a time-series database to make time-dependent queries easy. Midgard does not hold critical information. To interact with THORChain protocol, users should query THORNode directly.  # noqa: E501

    OpenAPI spec version: 2.20.1
    Contact: devs@thorchain.org
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class EarningsHistoryItemPool(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'asset_liquidity_fees': 'str',
        'earnings': 'str',
        'pool': 'str',
        'rewards': 'str',
        'rune_liquidity_fees': 'str',
        'saver_earning': 'str',
        'total_liquidity_fees_rune': 'str'
    }

    attribute_map = {
        'asset_liquidity_fees': 'assetLiquidityFees',
        'earnings': 'earnings',
        'pool': 'pool',
        'rewards': 'rewards',
        'rune_liquidity_fees': 'runeLiquidityFees',
        'saver_earning': 'saverEarning',
        'total_liquidity_fees_rune': 'totalLiquidityFeesRune'
    }

    def __init__(self, asset_liquidity_fees=None, earnings=None, pool=None, rewards=None, rune_liquidity_fees=None, saver_earning=None, total_liquidity_fees_rune=None):  # noqa: E501
        """EarningsHistoryItemPool - a model defined in Swagger"""  # noqa: E501
        self._asset_liquidity_fees = None
        self._earnings = None
        self._pool = None
        self._rewards = None
        self._rune_liquidity_fees = None
        self._saver_earning = None
        self._total_liquidity_fees_rune = None
        self.discriminator = None
        self.asset_liquidity_fees = asset_liquidity_fees
        self.earnings = earnings
        self.pool = pool
        self.rewards = rewards
        self.rune_liquidity_fees = rune_liquidity_fees
        self.saver_earning = saver_earning
        self.total_liquidity_fees_rune = total_liquidity_fees_rune

    @property
    def asset_liquidity_fees(self):
        """Gets the asset_liquidity_fees of this EarningsHistoryItemPool.  # noqa: E501

        Int64(e8), liquidity fees collected in the pool's asset  # noqa: E501

        :return: The asset_liquidity_fees of this EarningsHistoryItemPool.  # noqa: E501
        :rtype: str
        """
        return self._asset_liquidity_fees

    @asset_liquidity_fees.setter
    def asset_liquidity_fees(self, asset_liquidity_fees):
        """Sets the asset_liquidity_fees of this EarningsHistoryItemPool.

        Int64(e8), liquidity fees collected in the pool's asset  # noqa: E501

        :param asset_liquidity_fees: The asset_liquidity_fees of this EarningsHistoryItemPool.  # noqa: E501
        :type: str
        """
        if asset_liquidity_fees is None:
            raise ValueError("Invalid value for `asset_liquidity_fees`, must not be `None`")  # noqa: E501

        self._asset_liquidity_fees = asset_liquidity_fees

    @property
    def earnings(self):
        """Gets the earnings of this EarningsHistoryItemPool.  # noqa: E501

        Int64(e8), total earnings in RUNE (totalLiquidityFees + rewards)  # noqa: E501

        :return: The earnings of this EarningsHistoryItemPool.  # noqa: E501
        :rtype: str
        """
        return self._earnings

    @earnings.setter
    def earnings(self, earnings):
        """Sets the earnings of this EarningsHistoryItemPool.

        Int64(e8), total earnings in RUNE (totalLiquidityFees + rewards)  # noqa: E501

        :param earnings: The earnings of this EarningsHistoryItemPool.  # noqa: E501
        :type: str
        """
        if earnings is None:
            raise ValueError("Invalid value for `earnings`, must not be `None`")  # noqa: E501

        self._earnings = earnings

    @property
    def pool(self):
        """Gets the pool of this EarningsHistoryItemPool.  # noqa: E501

        asset for the given pool  # noqa: E501

        :return: The pool of this EarningsHistoryItemPool.  # noqa: E501
        :rtype: str
        """
        return self._pool

    @pool.setter
    def pool(self, pool):
        """Sets the pool of this EarningsHistoryItemPool.

        asset for the given pool  # noqa: E501

        :param pool: The pool of this EarningsHistoryItemPool.  # noqa: E501
        :type: str
        """
        if pool is None:
            raise ValueError("Invalid value for `pool`, must not be `None`")  # noqa: E501

        self._pool = pool

    @property
    def rewards(self):
        """Gets the rewards of this EarningsHistoryItemPool.  # noqa: E501

        Int64(e8), RUNE amount sent to (positive) or taken from (negative) the pool as a result of balancing it's share of system income each block   # noqa: E501

        :return: The rewards of this EarningsHistoryItemPool.  # noqa: E501
        :rtype: str
        """
        return self._rewards

    @rewards.setter
    def rewards(self, rewards):
        """Sets the rewards of this EarningsHistoryItemPool.

        Int64(e8), RUNE amount sent to (positive) or taken from (negative) the pool as a result of balancing it's share of system income each block   # noqa: E501

        :param rewards: The rewards of this EarningsHistoryItemPool.  # noqa: E501
        :type: str
        """
        if rewards is None:
            raise ValueError("Invalid value for `rewards`, must not be `None`")  # noqa: E501

        self._rewards = rewards

    @property
    def rune_liquidity_fees(self):
        """Gets the rune_liquidity_fees of this EarningsHistoryItemPool.  # noqa: E501

        Int64(e8), liquidity fees collected in RUNE  # noqa: E501

        :return: The rune_liquidity_fees of this EarningsHistoryItemPool.  # noqa: E501
        :rtype: str
        """
        return self._rune_liquidity_fees

    @rune_liquidity_fees.setter
    def rune_liquidity_fees(self, rune_liquidity_fees):
        """Sets the rune_liquidity_fees of this EarningsHistoryItemPool.

        Int64(e8), liquidity fees collected in RUNE  # noqa: E501

        :param rune_liquidity_fees: The rune_liquidity_fees of this EarningsHistoryItemPool.  # noqa: E501
        :type: str
        """
        if rune_liquidity_fees is None:
            raise ValueError("Invalid value for `rune_liquidity_fees`, must not be `None`")  # noqa: E501

        self._rune_liquidity_fees = rune_liquidity_fees

    @property
    def saver_earning(self):
        """Gets the saver_earning of this EarningsHistoryItemPool.  # noqa: E501

        Int64(e8), total saver reward collected by the pool, shown in pool's ASSET   # noqa: E501

        :return: The saver_earning of this EarningsHistoryItemPool.  # noqa: E501
        :rtype: str
        """
        return self._saver_earning

    @saver_earning.setter
    def saver_earning(self, saver_earning):
        """Sets the saver_earning of this EarningsHistoryItemPool.

        Int64(e8), total saver reward collected by the pool, shown in pool's ASSET   # noqa: E501

        :param saver_earning: The saver_earning of this EarningsHistoryItemPool.  # noqa: E501
        :type: str
        """
        if saver_earning is None:
            raise ValueError("Invalid value for `saver_earning`, must not be `None`")  # noqa: E501

        self._saver_earning = saver_earning

    @property
    def total_liquidity_fees_rune(self):
        """Gets the total_liquidity_fees_rune of this EarningsHistoryItemPool.  # noqa: E501

        Int64(e8), total liquidity fees (assetFees + runeFees) collected, shown in RUNE   # noqa: E501

        :return: The total_liquidity_fees_rune of this EarningsHistoryItemPool.  # noqa: E501
        :rtype: str
        """
        return self._total_liquidity_fees_rune

    @total_liquidity_fees_rune.setter
    def total_liquidity_fees_rune(self, total_liquidity_fees_rune):
        """Sets the total_liquidity_fees_rune of this EarningsHistoryItemPool.

        Int64(e8), total liquidity fees (assetFees + runeFees) collected, shown in RUNE   # noqa: E501

        :param total_liquidity_fees_rune: The total_liquidity_fees_rune of this EarningsHistoryItemPool.  # noqa: E501
        :type: str
        """
        if total_liquidity_fees_rune is None:
            raise ValueError("Invalid value for `total_liquidity_fees_rune`, must not be `None`")  # noqa: E501

        self._total_liquidity_fees_rune = total_liquidity_fees_rune

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(EarningsHistoryItemPool, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EarningsHistoryItemPool):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
